# coding: utf-8

"""
    videoplatform-api

    Interview Screening APIs allows to invite candidate to interview, evaluate and review candidates interview performances.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class EnableOneWayInterviewResponseData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'job_id': 'str',
        'odva_template_config': 'EnableOneWayInterviewResponseDataOdvaTemplateConfig',
        'type': 'str',
        'auto_reminder_data': 'EnableOneWayInterviewResponseDataAutoReminderData',
        'enable_status': 'bool',
        'date_created': 'int',
        'last_updated': 'int'
    }

    attribute_map = {
        'job_id': 'jobId',
        'odva_template_config': 'odvaTemplateConfig',
        'type': 'type',
        'auto_reminder_data': 'autoReminderData',
        'enable_status': 'enableStatus',
        'date_created': 'dateCreated',
        'last_updated': 'lastUpdated'
    }

    def __init__(self, job_id=None, odva_template_config=None, type=None, auto_reminder_data=None, enable_status=None, date_created=None, last_updated=None):  # noqa: E501
        """EnableOneWayInterviewResponseData - a model defined in Swagger"""  # noqa: E501
        self._job_id = None
        self._odva_template_config = None
        self._type = None
        self._auto_reminder_data = None
        self._enable_status = None
        self._date_created = None
        self._last_updated = None
        self.discriminator = None
        self.job_id = job_id
        self.odva_template_config = odva_template_config
        if type is not None:
            self.type = type
        self.auto_reminder_data = auto_reminder_data
        self.enable_status = enable_status
        self.date_created = date_created
        self.last_updated = last_updated

    @property
    def job_id(self):
        """Gets the job_id of this EnableOneWayInterviewResponseData.  # noqa: E501

        JobId of a Job.  # noqa: E501

        :return: The job_id of this EnableOneWayInterviewResponseData.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this EnableOneWayInterviewResponseData.

        JobId of a Job.  # noqa: E501

        :param job_id: The job_id of this EnableOneWayInterviewResponseData.  # noqa: E501
        :type: str
        """
        if job_id is None:
            raise ValueError("Invalid value for `job_id`, must not be `None`")  # noqa: E501

        self._job_id = job_id

    @property
    def odva_template_config(self):
        """Gets the odva_template_config of this EnableOneWayInterviewResponseData.  # noqa: E501


        :return: The odva_template_config of this EnableOneWayInterviewResponseData.  # noqa: E501
        :rtype: EnableOneWayInterviewResponseDataOdvaTemplateConfig
        """
        return self._odva_template_config

    @odva_template_config.setter
    def odva_template_config(self, odva_template_config):
        """Sets the odva_template_config of this EnableOneWayInterviewResponseData.


        :param odva_template_config: The odva_template_config of this EnableOneWayInterviewResponseData.  # noqa: E501
        :type: EnableOneWayInterviewResponseDataOdvaTemplateConfig
        """
        if odva_template_config is None:
            raise ValueError("Invalid value for `odva_template_config`, must not be `None`")  # noqa: E501

        self._odva_template_config = odva_template_config

    @property
    def type(self):
        """Gets the type of this EnableOneWayInterviewResponseData.  # noqa: E501

        Config for a job or event.  # noqa: E501

        :return: The type of this EnableOneWayInterviewResponseData.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this EnableOneWayInterviewResponseData.

        Config for a job or event.  # noqa: E501

        :param type: The type of this EnableOneWayInterviewResponseData.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def auto_reminder_data(self):
        """Gets the auto_reminder_data of this EnableOneWayInterviewResponseData.  # noqa: E501


        :return: The auto_reminder_data of this EnableOneWayInterviewResponseData.  # noqa: E501
        :rtype: EnableOneWayInterviewResponseDataAutoReminderData
        """
        return self._auto_reminder_data

    @auto_reminder_data.setter
    def auto_reminder_data(self, auto_reminder_data):
        """Sets the auto_reminder_data of this EnableOneWayInterviewResponseData.


        :param auto_reminder_data: The auto_reminder_data of this EnableOneWayInterviewResponseData.  # noqa: E501
        :type: EnableOneWayInterviewResponseDataAutoReminderData
        """
        if auto_reminder_data is None:
            raise ValueError("Invalid value for `auto_reminder_data`, must not be `None`")  # noqa: E501

        self._auto_reminder_data = auto_reminder_data

    @property
    def enable_status(self):
        """Gets the enable_status of this EnableOneWayInterviewResponseData.  # noqa: E501

        true if one way interview is enabled else false.  # noqa: E501

        :return: The enable_status of this EnableOneWayInterviewResponseData.  # noqa: E501
        :rtype: bool
        """
        return self._enable_status

    @enable_status.setter
    def enable_status(self, enable_status):
        """Sets the enable_status of this EnableOneWayInterviewResponseData.

        true if one way interview is enabled else false.  # noqa: E501

        :param enable_status: The enable_status of this EnableOneWayInterviewResponseData.  # noqa: E501
        :type: bool
        """
        if enable_status is None:
            raise ValueError("Invalid value for `enable_status`, must not be `None`")  # noqa: E501

        self._enable_status = enable_status

    @property
    def date_created(self):
        """Gets the date_created of this EnableOneWayInterviewResponseData.  # noqa: E501

        Date of when the one way interview is enabled.  # noqa: E501

        :return: The date_created of this EnableOneWayInterviewResponseData.  # noqa: E501
        :rtype: int
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this EnableOneWayInterviewResponseData.

        Date of when the one way interview is enabled.  # noqa: E501

        :param date_created: The date_created of this EnableOneWayInterviewResponseData.  # noqa: E501
        :type: int
        """
        if date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def last_updated(self):
        """Gets the last_updated of this EnableOneWayInterviewResponseData.  # noqa: E501

        Date of when the one way interview is updated whether enabled or disabled.  # noqa: E501

        :return: The last_updated of this EnableOneWayInterviewResponseData.  # noqa: E501
        :rtype: int
        """
        return self._last_updated

    @last_updated.setter
    def last_updated(self, last_updated):
        """Sets the last_updated of this EnableOneWayInterviewResponseData.

        Date of when the one way interview is updated whether enabled or disabled.  # noqa: E501

        :param last_updated: The last_updated of this EnableOneWayInterviewResponseData.  # noqa: E501
        :type: int
        """
        if last_updated is None:
            raise ValueError("Invalid value for `last_updated`, must not be `None`")  # noqa: E501

        self._last_updated = last_updated

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EnableOneWayInterviewResponseData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EnableOneWayInterviewResponseData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ex-search-api

    These APIs helps in searching and providing suggestions based on keywords within employee profiles.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class EmployeeAggregationRequest(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'keyword': 'str',
        'common': 'CommonNode',
        'aggregations': 'AggregationsNode'
    }

    attribute_map = {
        'keyword': 'keyword',
        'common': 'common',
        'aggregations': 'aggregations'
    }

    def __init__(self, keyword=None, common=None, aggregations=None):  # noqa: E501
        """EmployeeAggregationRequest - a model defined in Swagger"""  # noqa: E501
        self._keyword = None
        self._common = None
        self._aggregations = None
        self.discriminator = None
        if keyword is not None:
            self.keyword = keyword
        if common is not None:
            self.common = common
        if aggregations is not None:
            self.aggregations = aggregations

    @property
    def keyword(self):
        """Gets the keyword of this EmployeeAggregationRequest.  # noqa: E501

        Keyword to search.  # noqa: E501

        :return: The keyword of this EmployeeAggregationRequest.  # noqa: E501
        :rtype: str
        """
        return self._keyword

    @keyword.setter
    def keyword(self, keyword):
        """Sets the keyword of this EmployeeAggregationRequest.

        Keyword to search.  # noqa: E501

        :param keyword: The keyword of this EmployeeAggregationRequest.  # noqa: E501
        :type: str
        """

        self._keyword = keyword

    @property
    def common(self):
        """Gets the common of this EmployeeAggregationRequest.  # noqa: E501


        :return: The common of this EmployeeAggregationRequest.  # noqa: E501
        :rtype: CommonNode
        """
        return self._common

    @common.setter
    def common(self, common):
        """Sets the common of this EmployeeAggregationRequest.


        :param common: The common of this EmployeeAggregationRequest.  # noqa: E501
        :type: CommonNode
        """

        self._common = common

    @property
    def aggregations(self):
        """Gets the aggregations of this EmployeeAggregationRequest.  # noqa: E501


        :return: The aggregations of this EmployeeAggregationRequest.  # noqa: E501
        :rtype: AggregationsNode
        """
        return self._aggregations

    @aggregations.setter
    def aggregations(self, aggregations):
        """Sets the aggregations of this EmployeeAggregationRequest.


        :param aggregations: The aggregations of this EmployeeAggregationRequest.  # noqa: E501
        :type: AggregationsNode
        """

        self._aggregations = aggregations

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EmployeeAggregationRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmployeeAggregationRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    recommendations-api

    These APIs provide job suggestions based on your profile, akin job listings, and nearby job opportunities tailored to your qualifications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class ProfileMatchingResponseSkillGap(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'exact_match': 'list[str]',
        'semantic_match': 'list[str]',
        'no_match': 'list[str]'
    }

    attribute_map = {
        'exact_match': 'exactMatch',
        'semantic_match': 'semanticMatch',
        'no_match': 'noMatch'
    }

    def __init__(self, exact_match=None, semantic_match=None, no_match=None):  # noqa: E501
        """ProfileMatchingResponseSkillGap - a model defined in Swagger"""  # noqa: E501
        self._exact_match = None
        self._semantic_match = None
        self._no_match = None
        self.discriminator = None
        if exact_match is not None:
            self.exact_match = exact_match
        if semantic_match is not None:
            self.semantic_match = semantic_match
        if no_match is not None:
            self.no_match = no_match

    @property
    def exact_match(self):
        """Gets the exact_match of this ProfileMatchingResponseSkillGap.  # noqa: E501

        Exact Matched Skills  # noqa: E501

        :return: The exact_match of this ProfileMatchingResponseSkillGap.  # noqa: E501
        :rtype: list[str]
        """
        return self._exact_match

    @exact_match.setter
    def exact_match(self, exact_match):
        """Sets the exact_match of this ProfileMatchingResponseSkillGap.

        Exact Matched Skills  # noqa: E501

        :param exact_match: The exact_match of this ProfileMatchingResponseSkillGap.  # noqa: E501
        :type: list[str]
        """

        self._exact_match = exact_match

    @property
    def semantic_match(self):
        """Gets the semantic_match of this ProfileMatchingResponseSkillGap.  # noqa: E501

        Semantically Matched Skills  # noqa: E501

        :return: The semantic_match of this ProfileMatchingResponseSkillGap.  # noqa: E501
        :rtype: list[str]
        """
        return self._semantic_match

    @semantic_match.setter
    def semantic_match(self, semantic_match):
        """Sets the semantic_match of this ProfileMatchingResponseSkillGap.

        Semantically Matched Skills  # noqa: E501

        :param semantic_match: The semantic_match of this ProfileMatchingResponseSkillGap.  # noqa: E501
        :type: list[str]
        """

        self._semantic_match = semantic_match

    @property
    def no_match(self):
        """Gets the no_match of this ProfileMatchingResponseSkillGap.  # noqa: E501

        UnMatched Skills  # noqa: E501

        :return: The no_match of this ProfileMatchingResponseSkillGap.  # noqa: E501
        :rtype: list[str]
        """
        return self._no_match

    @no_match.setter
    def no_match(self, no_match):
        """Sets the no_match of this ProfileMatchingResponseSkillGap.

        UnMatched Skills  # noqa: E501

        :param no_match: The no_match of this ProfileMatchingResponseSkillGap.  # noqa: E501
        :type: list[str]
        """

        self._no_match = no_match

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProfileMatchingResponseSkillGap, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProfileMatchingResponseSkillGap):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    job-parser-api

    The process of extracting important information from the raw job description is called Job Parsing. This information can include things like job titles, required skills, required experience, job duties, and qualifications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phenom.commons.api_client import ApiClient


class JobParsingApi(object):
    base_path = "/parser/job"  # your base path

    def __init__(self, token, gateway_url, apikey, api_client=None):
        if api_client is None:
            api_client = ApiClient(gateway_url + self.base_path, apikey, token)
        self.api_client = api_client

    def parse_job(self, body, **kwargs):  # noqa: E501
        """Job Parsing  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.parse_job(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param JDRequest body: (required)
        :return: JobResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.parse_job_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.parse_job_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def parse_job_with_http_info(self, body, **kwargs):  # noqa: E501
        """Job Parsing  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.parse_job_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param JDRequest body: (required)
        :return: JobResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method parse_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `parse_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/parse', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='JobResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetAllWorkflowResponseData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'workflow_name': 'str',
        'created_date': 'str',
        'updated_date': 'str',
        'stages': 'list[GetAllWorkflowResponseStages]',
        'created_by_recruiter_info': 'GetAllWorkflowResponseCreatedByRecruiterInfo',
        'workflow_id': 'str',
        'active_stages_count': 'int'
    }

    attribute_map = {
        'workflow_name': 'workflowName',
        'created_date': 'createdDate',
        'updated_date': 'updatedDate',
        'stages': 'stages',
        'created_by_recruiter_info': 'createdByRecruiterInfo',
        'workflow_id': 'workflowId',
        'active_stages_count': 'activeStagesCount'
    }

    def __init__(self, workflow_name=None, created_date=None, updated_date=None, stages=None, created_by_recruiter_info=None, workflow_id=None, active_stages_count=None):  # noqa: E501
        """GetAllWorkflowResponseData - a model defined in Swagger"""  # noqa: E501
        self._workflow_name = None
        self._created_date = None
        self._updated_date = None
        self._stages = None
        self._created_by_recruiter_info = None
        self._workflow_id = None
        self._active_stages_count = None
        self.discriminator = None
        self.workflow_name = workflow_name
        self.created_date = created_date
        self.updated_date = updated_date
        self.stages = stages
        self.created_by_recruiter_info = created_by_recruiter_info
        self.workflow_id = workflow_id
        self.active_stages_count = active_stages_count

    @property
    def workflow_name(self):
        """Gets the workflow_name of this GetAllWorkflowResponseData.  # noqa: E501

        The name of the workflow.  # noqa: E501

        :return: The workflow_name of this GetAllWorkflowResponseData.  # noqa: E501
        :rtype: str
        """
        return self._workflow_name

    @workflow_name.setter
    def workflow_name(self, workflow_name):
        """Sets the workflow_name of this GetAllWorkflowResponseData.

        The name of the workflow.  # noqa: E501

        :param workflow_name: The workflow_name of this GetAllWorkflowResponseData.  # noqa: E501
        :type: str
        """
        if workflow_name is None:
            raise ValueError("Invalid value for `workflow_name`, must not be `None`")  # noqa: E501

        self._workflow_name = workflow_name

    @property
    def created_date(self):
        """Gets the created_date of this GetAllWorkflowResponseData.  # noqa: E501

        The date when the workflow was created.  # noqa: E501

        :return: The created_date of this GetAllWorkflowResponseData.  # noqa: E501
        :rtype: str
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this GetAllWorkflowResponseData.

        The date when the workflow was created.  # noqa: E501

        :param created_date: The created_date of this GetAllWorkflowResponseData.  # noqa: E501
        :type: str
        """
        if created_date is None:
            raise ValueError("Invalid value for `created_date`, must not be `None`")  # noqa: E501

        self._created_date = created_date

    @property
    def updated_date(self):
        """Gets the updated_date of this GetAllWorkflowResponseData.  # noqa: E501

        The date when the workflow was last updated.  # noqa: E501

        :return: The updated_date of this GetAllWorkflowResponseData.  # noqa: E501
        :rtype: str
        """
        return self._updated_date

    @updated_date.setter
    def updated_date(self, updated_date):
        """Sets the updated_date of this GetAllWorkflowResponseData.

        The date when the workflow was last updated.  # noqa: E501

        :param updated_date: The updated_date of this GetAllWorkflowResponseData.  # noqa: E501
        :type: str
        """
        if updated_date is None:
            raise ValueError("Invalid value for `updated_date`, must not be `None`")  # noqa: E501

        self._updated_date = updated_date

    @property
    def stages(self):
        """Gets the stages of this GetAllWorkflowResponseData.  # noqa: E501

        An array containing details of workflow stages.  # noqa: E501

        :return: The stages of this GetAllWorkflowResponseData.  # noqa: E501
        :rtype: list[GetAllWorkflowResponseStages]
        """
        return self._stages

    @stages.setter
    def stages(self, stages):
        """Sets the stages of this GetAllWorkflowResponseData.

        An array containing details of workflow stages.  # noqa: E501

        :param stages: The stages of this GetAllWorkflowResponseData.  # noqa: E501
        :type: list[GetAllWorkflowResponseStages]
        """
        if stages is None:
            raise ValueError("Invalid value for `stages`, must not be `None`")  # noqa: E501

        self._stages = stages

    @property
    def created_by_recruiter_info(self):
        """Gets the created_by_recruiter_info of this GetAllWorkflowResponseData.  # noqa: E501


        :return: The created_by_recruiter_info of this GetAllWorkflowResponseData.  # noqa: E501
        :rtype: GetAllWorkflowResponseCreatedByRecruiterInfo
        """
        return self._created_by_recruiter_info

    @created_by_recruiter_info.setter
    def created_by_recruiter_info(self, created_by_recruiter_info):
        """Sets the created_by_recruiter_info of this GetAllWorkflowResponseData.


        :param created_by_recruiter_info: The created_by_recruiter_info of this GetAllWorkflowResponseData.  # noqa: E501
        :type: GetAllWorkflowResponseCreatedByRecruiterInfo
        """
        if created_by_recruiter_info is None:
            raise ValueError("Invalid value for `created_by_recruiter_info`, must not be `None`")  # noqa: E501

        self._created_by_recruiter_info = created_by_recruiter_info

    @property
    def workflow_id(self):
        """Gets the workflow_id of this GetAllWorkflowResponseData.  # noqa: E501

        The unique identifier for the workflow.  # noqa: E501

        :return: The workflow_id of this GetAllWorkflowResponseData.  # noqa: E501
        :rtype: str
        """
        return self._workflow_id

    @workflow_id.setter
    def workflow_id(self, workflow_id):
        """Sets the workflow_id of this GetAllWorkflowResponseData.

        The unique identifier for the workflow.  # noqa: E501

        :param workflow_id: The workflow_id of this GetAllWorkflowResponseData.  # noqa: E501
        :type: str
        """
        if workflow_id is None:
            raise ValueError("Invalid value for `workflow_id`, must not be `None`")  # noqa: E501

        self._workflow_id = workflow_id

    @property
    def active_stages_count(self):
        """Gets the active_stages_count of this GetAllWorkflowResponseData.  # noqa: E501

        The number of active stages in the workflow.  # noqa: E501

        :return: The active_stages_count of this GetAllWorkflowResponseData.  # noqa: E501
        :rtype: int
        """
        return self._active_stages_count

    @active_stages_count.setter
    def active_stages_count(self, active_stages_count):
        """Sets the active_stages_count of this GetAllWorkflowResponseData.

        The number of active stages in the workflow.  # noqa: E501

        :param active_stages_count: The active_stages_count of this GetAllWorkflowResponseData.  # noqa: E501
        :type: int
        """
        if active_stages_count is None:
            raise ValueError("Invalid value for `active_stages_count`, must not be `None`")  # noqa: E501

        self._active_stages_count = active_stages_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetAllWorkflowResponseData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetAllWorkflowResponseData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    prediction-api

    An API that predicts skills based on job titles and provided skill sets.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import models into model package
from phenom.api.prediction.models.bad_request import BadRequest
from phenom.api.prediction.models.error_response import ErrorResponse
from phenom.api.prediction.models.skill_prediction_request import SkillPredictionRequest
from phenom.api.prediction.models.skill_prediction_response import SkillPredictionResponse
from phenom.api.prediction.models.skill_result import SkillResult
from phenom.api.prediction.models.skill_results import SkillResults



# coding: utf-8

"""
    jobs-activities-api

    These API's allows you to perform activities on Jobs  # noqa: E501

    OpenAPI spec version: 1.0.3
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetJobAttachmentsResponseData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'attachment_date': 'str',
        'created_by_user_name': 'str',
        'attachment_name': 'str',
        'attachment_id': 'str',
        'created_by_user_email': 'str'
    }

    attribute_map = {
        'attachment_date': 'attachmentDate',
        'created_by_user_name': 'createdByUserName',
        'attachment_name': 'attachmentName',
        'attachment_id': 'attachmentId',
        'created_by_user_email': 'createdByUserEmail'
    }

    def __init__(self, attachment_date=None, created_by_user_name=None, attachment_name=None, attachment_id=None, created_by_user_email=None):  # noqa: E501
        """GetJobAttachmentsResponseData - a model defined in Swagger"""  # noqa: E501
        self._attachment_date = None
        self._created_by_user_name = None
        self._attachment_name = None
        self._attachment_id = None
        self._created_by_user_email = None
        self.discriminator = None
        self.attachment_date = attachment_date
        self.created_by_user_name = created_by_user_name
        self.attachment_name = attachment_name
        self.attachment_id = attachment_id
        self.created_by_user_email = created_by_user_email

    @property
    def attachment_date(self):
        """Gets the attachment_date of this GetJobAttachmentsResponseData.  # noqa: E501


        :return: The attachment_date of this GetJobAttachmentsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._attachment_date

    @attachment_date.setter
    def attachment_date(self, attachment_date):
        """Sets the attachment_date of this GetJobAttachmentsResponseData.


        :param attachment_date: The attachment_date of this GetJobAttachmentsResponseData.  # noqa: E501
        :type: str
        """
        if attachment_date is None:
            raise ValueError("Invalid value for `attachment_date`, must not be `None`")  # noqa: E501

        self._attachment_date = attachment_date

    @property
    def created_by_user_name(self):
        """Gets the created_by_user_name of this GetJobAttachmentsResponseData.  # noqa: E501


        :return: The created_by_user_name of this GetJobAttachmentsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._created_by_user_name

    @created_by_user_name.setter
    def created_by_user_name(self, created_by_user_name):
        """Sets the created_by_user_name of this GetJobAttachmentsResponseData.


        :param created_by_user_name: The created_by_user_name of this GetJobAttachmentsResponseData.  # noqa: E501
        :type: str
        """
        if created_by_user_name is None:
            raise ValueError("Invalid value for `created_by_user_name`, must not be `None`")  # noqa: E501

        self._created_by_user_name = created_by_user_name

    @property
    def attachment_name(self):
        """Gets the attachment_name of this GetJobAttachmentsResponseData.  # noqa: E501


        :return: The attachment_name of this GetJobAttachmentsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._attachment_name

    @attachment_name.setter
    def attachment_name(self, attachment_name):
        """Sets the attachment_name of this GetJobAttachmentsResponseData.


        :param attachment_name: The attachment_name of this GetJobAttachmentsResponseData.  # noqa: E501
        :type: str
        """
        if attachment_name is None:
            raise ValueError("Invalid value for `attachment_name`, must not be `None`")  # noqa: E501

        self._attachment_name = attachment_name

    @property
    def attachment_id(self):
        """Gets the attachment_id of this GetJobAttachmentsResponseData.  # noqa: E501


        :return: The attachment_id of this GetJobAttachmentsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._attachment_id

    @attachment_id.setter
    def attachment_id(self, attachment_id):
        """Sets the attachment_id of this GetJobAttachmentsResponseData.


        :param attachment_id: The attachment_id of this GetJobAttachmentsResponseData.  # noqa: E501
        :type: str
        """
        if attachment_id is None:
            raise ValueError("Invalid value for `attachment_id`, must not be `None`")  # noqa: E501

        self._attachment_id = attachment_id

    @property
    def created_by_user_email(self):
        """Gets the created_by_user_email of this GetJobAttachmentsResponseData.  # noqa: E501


        :return: The created_by_user_email of this GetJobAttachmentsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._created_by_user_email

    @created_by_user_email.setter
    def created_by_user_email(self, created_by_user_email):
        """Sets the created_by_user_email of this GetJobAttachmentsResponseData.


        :param created_by_user_email: The created_by_user_email of this GetJobAttachmentsResponseData.  # noqa: E501
        :type: str
        """
        if created_by_user_email is None:
            raise ValueError("Invalid value for `created_by_user_email`, must not be `None`")  # noqa: E501

        self._created_by_user_email = created_by_user_email

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetJobAttachmentsResponseData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetJobAttachmentsResponseData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    applicants-api

    This API collection enables seamless operations by facilitating the retrieval of essential applicant details, updating and managing hiring statuses for candidates, assigning multiple candidates as leads for specific job roles, and obtaining detailed activity logs associated with applicants.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import models into model package
from phenom.api.applicants.models.additional_fields import AdditionalFields
from phenom.api.applicants.models.additional_fields_data import AdditionalFieldsData
from phenom.api.applicants.models.additional_fields_update_request import AdditionalFieldsUpdateRequest
from phenom.api.applicants.models.additional_fields_update_response import AdditionalFieldsUpdateResponse
from phenom.api.applicants.models.applicants import Applicants
from phenom.api.applicants.models.applicants_data import ApplicantsData
from phenom.api.applicants.models.applicants_data_candidates import ApplicantsDataCandidates
from phenom.api.applicants.models.applicants_data_contacts import ApplicantsDataContacts
from phenom.api.applicants.models.applicants_pagination import ApplicantsPagination
from phenom.api.applicants.models.assign_candidates_to_job_request import AssignCandidatesToJobRequest
from phenom.api.applicants.models.assign_candidates_to_job_response import AssignCandidatesToJobResponse
from phenom.api.applicants.models.attachment import Attachment
from phenom.api.applicants.models.attachment_data import AttachmentData
from phenom.api.applicants.models.attachment_data_attachments import AttachmentDataAttachments
from phenom.api.applicants.models.bad_request import BadRequest
from phenom.api.applicants.models.candidate_applications import CandidateApplications
from phenom.api.applicants.models.candidate_applications_data import CandidateApplicationsData
from phenom.api.applicants.models.error import Error
from phenom.api.applicants.models.hiring_status import HiringStatus
from phenom.api.applicants.models.hiring_status_activities import HiringStatusActivities
from phenom.api.applicants.models.hiring_status_activities_data import HiringStatusActivitiesData
from phenom.api.applicants.models.hiring_status_activities_pagination import HiringStatusActivitiesPagination
from phenom.api.applicants.models.hiring_status_data import HiringStatusData
from phenom.api.applicants.models.hiring_status_data_applications import HiringStatusDataApplications
from phenom.api.applicants.models.hiring_status_data_applications_close import HiringStatusDataApplicationsClose
from phenom.api.applicants.models.hiring_status_data_applications_hiring_status import HiringStatusDataApplicationsHiringStatus
from phenom.api.applicants.models.hiring_status_update_request import HiringStatusUpdateRequest
from phenom.api.applicants.models.hiring_status_update_response import HiringStatusUpdateResponse
from phenom.api.applicants.models.job_activities import JobActivities
from phenom.api.applicants.models.job_activities_data import JobActivitiesData
from phenom.api.applicants.models.job_activities_pagination import JobActivitiesPagination
from phenom.api.applicants.models.job_activities_traffic_source_list import JobActivitiesTrafficSourceList
from phenom.api.applicants.models.next_hiring_status import NextHiringStatus
from phenom.api.applicants.models.next_hiring_status_data import NextHiringStatusData
from phenom.api.applicants.models.next_hiring_status_data_hiring_status_list import NextHiringStatusDataHiringStatusList
from phenom.api.applicants.models.next_hiring_status_data_transition_statuses import NextHiringStatusDataTransitionStatuses
from phenom.api.applicants.models.no_content import NoContent



# coding: utf-8

"""
    jobsync-api

    Job Sync enables the user to manage jobs (view, create, update and delete jobs) in the Phenom database directly from the ATS, with the updates reflected on the career site.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: shravan.malla@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class JobResponseDTO(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'apply_url': 'str',
        'category': 'str',
        'company_name': 'str',
        'description': 'str',
        'job_id': 'str',
        'locale': 'str',
        'req_id': 'str',
        'site_type': 'str',
        'title': 'str',
        'employment_type': 'str',
        'city': 'str',
        'state': 'str',
        'country': 'str',
        'address': 'str',
        'postal_code': 'str',
        'hiring_manager_email': 'str',
        'hiring_manager_name': 'str',
        'recruiter_email': 'str',
        'recruiter_name': 'str',
        'source': 'str',
        'display_career_site': 'bool',
        'multi_location': 'list[LocationDTO]',
        'multi_category': 'list[Category]',
        'multi_recruiter': 'list[Recruiter]',
        'additional_fields': 'object',
        'visibility_locale': 'list[str]',
        'visibility_site_type': 'list[str]'
    }

    attribute_map = {
        'apply_url': 'applyUrl',
        'category': 'category',
        'company_name': 'companyName',
        'description': 'description',
        'job_id': 'jobId',
        'locale': 'locale',
        'req_id': 'reqId',
        'site_type': 'siteType',
        'title': 'title',
        'employment_type': 'employmentType',
        'city': 'city',
        'state': 'state',
        'country': 'country',
        'address': 'address',
        'postal_code': 'postalCode',
        'hiring_manager_email': 'hiringManagerEmail',
        'hiring_manager_name': 'hiringManagerName',
        'recruiter_email': 'recruiterEmail',
        'recruiter_name': 'recruiterName',
        'source': 'source',
        'display_career_site': 'displayCareerSite',
        'multi_location': 'multiLocation',
        'multi_category': 'multiCategory',
        'multi_recruiter': 'multiRecruiter',
        'additional_fields': 'additionalFields',
        'visibility_locale': 'visibilityLocale',
        'visibility_site_type': 'visibilitySiteType'
    }

    def __init__(self, apply_url=None, category=None, company_name=None, description=None, job_id=None, locale=None, req_id=None, site_type=None, title=None, employment_type=None, city=None, state=None, country=None, address=None, postal_code=None, hiring_manager_email=None, hiring_manager_name=None, recruiter_email=None, recruiter_name=None, source=None, display_career_site=None, multi_location=None, multi_category=None, multi_recruiter=None, additional_fields=None, visibility_locale=None, visibility_site_type=None):  # noqa: E501
        """JobResponseDTO - a model defined in Swagger"""  # noqa: E501
        self._apply_url = None
        self._category = None
        self._company_name = None
        self._description = None
        self._job_id = None
        self._locale = None
        self._req_id = None
        self._site_type = None
        self._title = None
        self._employment_type = None
        self._city = None
        self._state = None
        self._country = None
        self._address = None
        self._postal_code = None
        self._hiring_manager_email = None
        self._hiring_manager_name = None
        self._recruiter_email = None
        self._recruiter_name = None
        self._source = None
        self._display_career_site = None
        self._multi_location = None
        self._multi_category = None
        self._multi_recruiter = None
        self._additional_fields = None
        self._visibility_locale = None
        self._visibility_site_type = None
        self.discriminator = None
        if apply_url is not None:
            self.apply_url = apply_url
        if category is not None:
            self.category = category
        if company_name is not None:
            self.company_name = company_name
        if description is not None:
            self.description = description
        if job_id is not None:
            self.job_id = job_id
        if locale is not None:
            self.locale = locale
        if req_id is not None:
            self.req_id = req_id
        if site_type is not None:
            self.site_type = site_type
        if title is not None:
            self.title = title
        if employment_type is not None:
            self.employment_type = employment_type
        if city is not None:
            self.city = city
        if state is not None:
            self.state = state
        if country is not None:
            self.country = country
        if address is not None:
            self.address = address
        if postal_code is not None:
            self.postal_code = postal_code
        if hiring_manager_email is not None:
            self.hiring_manager_email = hiring_manager_email
        if hiring_manager_name is not None:
            self.hiring_manager_name = hiring_manager_name
        if recruiter_email is not None:
            self.recruiter_email = recruiter_email
        if recruiter_name is not None:
            self.recruiter_name = recruiter_name
        if source is not None:
            self.source = source
        if display_career_site is not None:
            self.display_career_site = display_career_site
        if multi_location is not None:
            self.multi_location = multi_location
        if multi_category is not None:
            self.multi_category = multi_category
        if multi_recruiter is not None:
            self.multi_recruiter = multi_recruiter
        if additional_fields is not None:
            self.additional_fields = additional_fields
        if visibility_locale is not None:
            self.visibility_locale = visibility_locale
        if visibility_site_type is not None:
            self.visibility_site_type = visibility_site_type

    @property
    def apply_url(self):
        """Gets the apply_url of this JobResponseDTO.  # noqa: E501

        Apply url of the job.  # noqa: E501

        :return: The apply_url of this JobResponseDTO.  # noqa: E501
        :rtype: str
        """
        return self._apply_url

    @apply_url.setter
    def apply_url(self, apply_url):
        """Sets the apply_url of this JobResponseDTO.

        Apply url of the job.  # noqa: E501

        :param apply_url: The apply_url of this JobResponseDTO.  # noqa: E501
        :type: str
        """

        self._apply_url = apply_url

    @property
    def category(self):
        """Gets the category of this JobResponseDTO.  # noqa: E501

        Phenom job category.  # noqa: E501

        :return: The category of this JobResponseDTO.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this JobResponseDTO.

        Phenom job category.  # noqa: E501

        :param category: The category of this JobResponseDTO.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def company_name(self):
        """Gets the company_name of this JobResponseDTO.  # noqa: E501

        Tenant name.  # noqa: E501

        :return: The company_name of this JobResponseDTO.  # noqa: E501
        :rtype: str
        """
        return self._company_name

    @company_name.setter
    def company_name(self, company_name):
        """Sets the company_name of this JobResponseDTO.

        Tenant name.  # noqa: E501

        :param company_name: The company_name of this JobResponseDTO.  # noqa: E501
        :type: str
        """

        self._company_name = company_name

    @property
    def description(self):
        """Gets the description of this JobResponseDTO.  # noqa: E501

        ATS job description.  # noqa: E501

        :return: The description of this JobResponseDTO.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this JobResponseDTO.

        ATS job description.  # noqa: E501

        :param description: The description of this JobResponseDTO.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def job_id(self):
        """Gets the job_id of this JobResponseDTO.  # noqa: E501

        ATS jobId.  # noqa: E501

        :return: The job_id of this JobResponseDTO.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this JobResponseDTO.

        ATS jobId.  # noqa: E501

        :param job_id: The job_id of this JobResponseDTO.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def locale(self):
        """Gets the locale of this JobResponseDTO.  # noqa: E501

        Locale of the site (Language_Country).  # noqa: E501

        :return: The locale of this JobResponseDTO.  # noqa: E501
        :rtype: str
        """
        return self._locale

    @locale.setter
    def locale(self, locale):
        """Sets the locale of this JobResponseDTO.

        Locale of the site (Language_Country).  # noqa: E501

        :param locale: The locale of this JobResponseDTO.  # noqa: E501
        :type: str
        """

        self._locale = locale

    @property
    def req_id(self):
        """Gets the req_id of this JobResponseDTO.  # noqa: E501

        ATS requisition id.  # noqa: E501

        :return: The req_id of this JobResponseDTO.  # noqa: E501
        :rtype: str
        """
        return self._req_id

    @req_id.setter
    def req_id(self, req_id):
        """Sets the req_id of this JobResponseDTO.

        ATS requisition id.  # noqa: E501

        :param req_id: The req_id of this JobResponseDTO.  # noqa: E501
        :type: str
        """

        self._req_id = req_id

    @property
    def site_type(self):
        """Gets the site_type of this JobResponseDTO.  # noqa: E501

        Persona that the job belongs to.  # noqa: E501

        :return: The site_type of this JobResponseDTO.  # noqa: E501
        :rtype: str
        """
        return self._site_type

    @site_type.setter
    def site_type(self, site_type):
        """Sets the site_type of this JobResponseDTO.

        Persona that the job belongs to.  # noqa: E501

        :param site_type: The site_type of this JobResponseDTO.  # noqa: E501
        :type: str
        """

        self._site_type = site_type

    @property
    def title(self):
        """Gets the title of this JobResponseDTO.  # noqa: E501

        ATS job title.  # noqa: E501

        :return: The title of this JobResponseDTO.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this JobResponseDTO.

        ATS job title.  # noqa: E501

        :param title: The title of this JobResponseDTO.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def employment_type(self):
        """Gets the employment_type of this JobResponseDTO.  # noqa: E501

        Type that the job belongs to.  # noqa: E501

        :return: The employment_type of this JobResponseDTO.  # noqa: E501
        :rtype: str
        """
        return self._employment_type

    @employment_type.setter
    def employment_type(self, employment_type):
        """Sets the employment_type of this JobResponseDTO.

        Type that the job belongs to.  # noqa: E501

        :param employment_type: The employment_type of this JobResponseDTO.  # noqa: E501
        :type: str
        """

        self._employment_type = employment_type

    @property
    def city(self):
        """Gets the city of this JobResponseDTO.  # noqa: E501

        ATS job posting city name.  # noqa: E501

        :return: The city of this JobResponseDTO.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this JobResponseDTO.

        ATS job posting city name.  # noqa: E501

        :param city: The city of this JobResponseDTO.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def state(self):
        """Gets the state of this JobResponseDTO.  # noqa: E501

        ATS job posting state name.  # noqa: E501

        :return: The state of this JobResponseDTO.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this JobResponseDTO.

        ATS job posting state name.  # noqa: E501

        :param state: The state of this JobResponseDTO.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def country(self):
        """Gets the country of this JobResponseDTO.  # noqa: E501

        ATS job posting country name.  # noqa: E501

        :return: The country of this JobResponseDTO.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this JobResponseDTO.

        ATS job posting country name.  # noqa: E501

        :param country: The country of this JobResponseDTO.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def address(self):
        """Gets the address of this JobResponseDTO.  # noqa: E501

        ATS job posting address.  # noqa: E501

        :return: The address of this JobResponseDTO.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this JobResponseDTO.

        ATS job posting address.  # noqa: E501

        :param address: The address of this JobResponseDTO.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def postal_code(self):
        """Gets the postal_code of this JobResponseDTO.  # noqa: E501

        ATS job posting location zip code.  # noqa: E501

        :return: The postal_code of this JobResponseDTO.  # noqa: E501
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """Sets the postal_code of this JobResponseDTO.

        ATS job posting location zip code.  # noqa: E501

        :param postal_code: The postal_code of this JobResponseDTO.  # noqa: E501
        :type: str
        """

        self._postal_code = postal_code

    @property
    def hiring_manager_email(self):
        """Gets the hiring_manager_email of this JobResponseDTO.  # noqa: E501

        Email of hiring manager associated to the job.  # noqa: E501

        :return: The hiring_manager_email of this JobResponseDTO.  # noqa: E501
        :rtype: str
        """
        return self._hiring_manager_email

    @hiring_manager_email.setter
    def hiring_manager_email(self, hiring_manager_email):
        """Sets the hiring_manager_email of this JobResponseDTO.

        Email of hiring manager associated to the job.  # noqa: E501

        :param hiring_manager_email: The hiring_manager_email of this JobResponseDTO.  # noqa: E501
        :type: str
        """

        self._hiring_manager_email = hiring_manager_email

    @property
    def hiring_manager_name(self):
        """Gets the hiring_manager_name of this JobResponseDTO.  # noqa: E501

        Name of hiring manager associated to the job.  # noqa: E501

        :return: The hiring_manager_name of this JobResponseDTO.  # noqa: E501
        :rtype: str
        """
        return self._hiring_manager_name

    @hiring_manager_name.setter
    def hiring_manager_name(self, hiring_manager_name):
        """Sets the hiring_manager_name of this JobResponseDTO.

        Name of hiring manager associated to the job.  # noqa: E501

        :param hiring_manager_name: The hiring_manager_name of this JobResponseDTO.  # noqa: E501
        :type: str
        """

        self._hiring_manager_name = hiring_manager_name

    @property
    def recruiter_email(self):
        """Gets the recruiter_email of this JobResponseDTO.  # noqa: E501

        Email of the recruiter assigned to the job.  # noqa: E501

        :return: The recruiter_email of this JobResponseDTO.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_email

    @recruiter_email.setter
    def recruiter_email(self, recruiter_email):
        """Sets the recruiter_email of this JobResponseDTO.

        Email of the recruiter assigned to the job.  # noqa: E501

        :param recruiter_email: The recruiter_email of this JobResponseDTO.  # noqa: E501
        :type: str
        """

        self._recruiter_email = recruiter_email

    @property
    def recruiter_name(self):
        """Gets the recruiter_name of this JobResponseDTO.  # noqa: E501

        Name of the recruiter assigned to the job.  # noqa: E501

        :return: The recruiter_name of this JobResponseDTO.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_name

    @recruiter_name.setter
    def recruiter_name(self, recruiter_name):
        """Sets the recruiter_name of this JobResponseDTO.

        Name of the recruiter assigned to the job.  # noqa: E501

        :param recruiter_name: The recruiter_name of this JobResponseDTO.  # noqa: E501
        :type: str
        """

        self._recruiter_name = recruiter_name

    @property
    def source(self):
        """Gets the source of this JobResponseDTO.  # noqa: E501

        Job source.  # noqa: E501

        :return: The source of this JobResponseDTO.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this JobResponseDTO.

        Job source.  # noqa: E501

        :param source: The source of this JobResponseDTO.  # noqa: E501
        :type: str
        """

        self._source = source

    @property
    def display_career_site(self):
        """Gets the display_career_site of this JobResponseDTO.  # noqa: E501

        To display the job on career site or not.  # noqa: E501

        :return: The display_career_site of this JobResponseDTO.  # noqa: E501
        :rtype: bool
        """
        return self._display_career_site

    @display_career_site.setter
    def display_career_site(self, display_career_site):
        """Sets the display_career_site of this JobResponseDTO.

        To display the job on career site or not.  # noqa: E501

        :param display_career_site: The display_career_site of this JobResponseDTO.  # noqa: E501
        :type: bool
        """

        self._display_career_site = display_career_site

    @property
    def multi_location(self):
        """Gets the multi_location of this JobResponseDTO.  # noqa: E501

        All job posting locations, includes /excludes primary posting location.  # noqa: E501

        :return: The multi_location of this JobResponseDTO.  # noqa: E501
        :rtype: list[LocationDTO]
        """
        return self._multi_location

    @multi_location.setter
    def multi_location(self, multi_location):
        """Sets the multi_location of this JobResponseDTO.

        All job posting locations, includes /excludes primary posting location.  # noqa: E501

        :param multi_location: The multi_location of this JobResponseDTO.  # noqa: E501
        :type: list[LocationDTO]
        """

        self._multi_location = multi_location

    @property
    def multi_category(self):
        """Gets the multi_category of this JobResponseDTO.  # noqa: E501

        All categories that the job belongs to.  # noqa: E501

        :return: The multi_category of this JobResponseDTO.  # noqa: E501
        :rtype: list[Category]
        """
        return self._multi_category

    @multi_category.setter
    def multi_category(self, multi_category):
        """Sets the multi_category of this JobResponseDTO.

        All categories that the job belongs to.  # noqa: E501

        :param multi_category: The multi_category of this JobResponseDTO.  # noqa: E501
        :type: list[Category]
        """

        self._multi_category = multi_category

    @property
    def multi_recruiter(self):
        """Gets the multi_recruiter of this JobResponseDTO.  # noqa: E501

        Data of recruiters assigned to the job(array).  # noqa: E501

        :return: The multi_recruiter of this JobResponseDTO.  # noqa: E501
        :rtype: list[Recruiter]
        """
        return self._multi_recruiter

    @multi_recruiter.setter
    def multi_recruiter(self, multi_recruiter):
        """Sets the multi_recruiter of this JobResponseDTO.

        Data of recruiters assigned to the job(array).  # noqa: E501

        :param multi_recruiter: The multi_recruiter of this JobResponseDTO.  # noqa: E501
        :type: list[Recruiter]
        """

        self._multi_recruiter = multi_recruiter

    @property
    def additional_fields(self):
        """Gets the additional_fields of this JobResponseDTO.  # noqa: E501

        Additional fields associated to the job.  # noqa: E501

        :return: The additional_fields of this JobResponseDTO.  # noqa: E501
        :rtype: object
        """
        return self._additional_fields

    @additional_fields.setter
    def additional_fields(self, additional_fields):
        """Sets the additional_fields of this JobResponseDTO.

        Additional fields associated to the job.  # noqa: E501

        :param additional_fields: The additional_fields of this JobResponseDTO.  # noqa: E501
        :type: object
        """

        self._additional_fields = additional_fields

    @property
    def visibility_locale(self):
        """Gets the visibility_locale of this JobResponseDTO.  # noqa: E501

        All locales that the job belongs to.  # noqa: E501

        :return: The visibility_locale of this JobResponseDTO.  # noqa: E501
        :rtype: list[str]
        """
        return self._visibility_locale

    @visibility_locale.setter
    def visibility_locale(self, visibility_locale):
        """Sets the visibility_locale of this JobResponseDTO.

        All locales that the job belongs to.  # noqa: E501

        :param visibility_locale: The visibility_locale of this JobResponseDTO.  # noqa: E501
        :type: list[str]
        """

        self._visibility_locale = visibility_locale

    @property
    def visibility_site_type(self):
        """Gets the visibility_site_type of this JobResponseDTO.  # noqa: E501

        All personas that the jobs belongs to.  # noqa: E501

        :return: The visibility_site_type of this JobResponseDTO.  # noqa: E501
        :rtype: list[str]
        """
        return self._visibility_site_type

    @visibility_site_type.setter
    def visibility_site_type(self, visibility_site_type):
        """Sets the visibility_site_type of this JobResponseDTO.

        All personas that the jobs belongs to.  # noqa: E501

        :param visibility_site_type: The visibility_site_type of this JobResponseDTO.  # noqa: E501
        :type: list[str]
        """

        self._visibility_site_type = visibility_site_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobResponseDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobResponseDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetWorkflowResponseUpdatedByRecruiterInfo(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'recruiter_user_id': 'str'
    }

    attribute_map = {
        'recruiter_user_id': 'recruiterUserId'
    }

    def __init__(self, recruiter_user_id=None):  # noqa: E501
        """GetWorkflowResponseUpdatedByRecruiterInfo - a model defined in Swagger"""  # noqa: E501
        self._recruiter_user_id = None
        self.discriminator = None
        self.recruiter_user_id = recruiter_user_id

    @property
    def recruiter_user_id(self):
        """Gets the recruiter_user_id of this GetWorkflowResponseUpdatedByRecruiterInfo.  # noqa: E501

        ID of the recruiter who last updated the workflow.  # noqa: E501

        :return: The recruiter_user_id of this GetWorkflowResponseUpdatedByRecruiterInfo.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_user_id

    @recruiter_user_id.setter
    def recruiter_user_id(self, recruiter_user_id):
        """Sets the recruiter_user_id of this GetWorkflowResponseUpdatedByRecruiterInfo.

        ID of the recruiter who last updated the workflow.  # noqa: E501

        :param recruiter_user_id: The recruiter_user_id of this GetWorkflowResponseUpdatedByRecruiterInfo.  # noqa: E501
        :type: str
        """
        if recruiter_user_id is None:
            raise ValueError("Invalid value for `recruiter_user_id`, must not be `None`")  # noqa: E501

        self._recruiter_user_id = recruiter_user_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetWorkflowResponseUpdatedByRecruiterInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetWorkflowResponseUpdatedByRecruiterInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    employees-api

    The employee profile APIs are used to create, access, update and delete employee profile and preferences.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

from __future__ import absolute_import

# import models into model package
from phenom.api.employees.models.bad_request import BadRequest
from phenom.api.employees.models.create_employee_preference import CreateEmployeePreference
from phenom.api.employees.models.create_employee_profile import CreateEmployeeProfile
from phenom.api.employees.models.employee_preference import EmployeePreference
from phenom.api.employees.models.employee_preference_success_response import EmployeePreferenceSuccessResponse
from phenom.api.employees.models.employee_profile import EmployeeProfile
from phenom.api.employees.models.employee_profile_success_response import EmployeeProfileSuccessResponse
from phenom.api.employees.models.employees_api_success_response import EmployeesAPISuccessResponse
from phenom.api.employees.models.error_response import ErrorResponse
from phenom.api.employees.models.update_employee_preference import UpdateEmployeePreference
from phenom.api.employees.models.update_employee_profile import UpdateEmployeeProfile



# coding: utf-8

"""
    aisourcing-api

    AI matching FitScore provides a concise assessment indicating how well a candidate aligns with a job based on their skills, experience, and qualifications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class FitScoreRequest(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'user_id': 'str',
        'user_profile': 'UserProfileFitScore',
        'job_ids': 'list[str]'
    }

    attribute_map = {
        'user_id': 'userId',
        'user_profile': 'userProfile',
        'job_ids': 'jobIds'
    }

    def __init__(self, user_id=None, user_profile=None, job_ids=None):  # noqa: E501
        """FitScoreRequest - a model defined in Swagger"""  # noqa: E501
        self._user_id = None
        self._user_profile = None
        self._job_ids = None
        self.discriminator = None
        if user_id is not None:
            self.user_id = user_id
        if user_profile is not None:
            self.user_profile = user_profile
        if job_ids is not None:
            self.job_ids = job_ids

    @property
    def user_id(self):
        """Gets the user_id of this FitScoreRequest.  # noqa: E501

        User id of a job.  # noqa: E501

        :return: The user_id of this FitScoreRequest.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this FitScoreRequest.

        User id of a job.  # noqa: E501

        :param user_id: The user_id of this FitScoreRequest.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def user_profile(self):
        """Gets the user_profile of this FitScoreRequest.  # noqa: E501


        :return: The user_profile of this FitScoreRequest.  # noqa: E501
        :rtype: UserProfileFitScore
        """
        return self._user_profile

    @user_profile.setter
    def user_profile(self, user_profile):
        """Sets the user_profile of this FitScoreRequest.


        :param user_profile: The user_profile of this FitScoreRequest.  # noqa: E501
        :type: UserProfileFitScore
        """

        self._user_profile = user_profile

    @property
    def job_ids(self):
        """Gets the job_ids of this FitScoreRequest.  # noqa: E501

        Job ids to check fitscore.  # noqa: E501

        :return: The job_ids of this FitScoreRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._job_ids

    @job_ids.setter
    def job_ids(self, job_ids):
        """Sets the job_ids of this FitScoreRequest.

        Job ids to check fitscore.  # noqa: E501

        :param job_ids: The job_ids of this FitScoreRequest.  # noqa: E501
        :type: list[str]
        """

        self._job_ids = job_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FitScoreRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FitScoreRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    jobs-activities-api

    These API's allows you to perform activities on Jobs  # noqa: E501

    OpenAPI spec version: 1.0.3
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import apis into sdk package
from phenom.api.jobactivities.hiring_team_api import HiringTeamApi
from phenom.api.jobactivities.job_attachments_api import JobAttachmentsApi
from phenom.api.jobactivities.job_category_api import JobCategoryApi
from phenom.api.jobactivities.job_notes_api import JobNotesApi
# import ApiClient
from phenom.commons.api_client import ApiClient
from phenom.commons.configuration import Configuration
# import models into sdk package
from phenom.api.jobactivities.models.bad_request_error import BadRequestError
from phenom.api.jobactivities.models.bad_request_error_errors import BadRequestErrorErrors
from phenom.api.jobactivities.models.create_job_note_request import CreateJobNoteRequest
from phenom.api.jobactivities.models.create_job_note_response import CreateJobNoteResponse
from phenom.api.jobactivities.models.get_job_attachments_response import GetJobAttachmentsResponse
from phenom.api.jobactivities.models.get_job_attachments_response_data import GetJobAttachmentsResponseData
from phenom.api.jobactivities.models.get_job_categories import GetJobCategories
from phenom.api.jobactivities.models.get_job_notes_response import GetJobNotesResponse
from phenom.api.jobactivities.models.get_job_notes_response_pagination import GetJobNotesResponsePagination
from phenom.api.jobactivities.models.hiring_team import HiringTeam
from phenom.api.jobactivities.models.hiring_team_hiring_team_list import HiringTeamHiringTeamList
from phenom.api.jobactivities.models.internal_server_error_response import InternalServerErrorResponse
from phenom.api.jobactivities.models.no_content_response import NoContentResponse
from phenom.api.jobactivities.models.not_found_error import NotFoundError
from phenom.api.jobactivities.models.update_hiring_team_response import UpdateHiringTeamResponse
from phenom.api.jobactivities.models.update_jobs_hiring_team_request import UpdateJobsHiringTeamRequest
from phenom.api.jobactivities.models.update_jobs_hiring_team_request_hiring_team_list import UpdateJobsHiringTeamRequestHiringTeamList



# coding: utf-8

"""
    videoplatform-api

    Interview Screening APIs allows to invite candidate to interview, evaluate and review candidates interview performances.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GiveEvaluationRequest(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'overall_evaluation': 'str',
        'overall_evaluation_status': 'str',
        'recruiter_user_id': 'str',
        'video_screen_id': 'str',
        'answer_ratings': 'list[GiveEvaluationRequestAnswerRatings]',
        'role_name': 'str'
    }

    attribute_map = {
        'overall_evaluation': 'overallEvaluation',
        'overall_evaluation_status': 'overallEvaluationStatus',
        'recruiter_user_id': 'recruiterUserId',
        'video_screen_id': 'videoScreenId',
        'answer_ratings': 'answerRatings',
        'role_name': 'roleName'
    }

    def __init__(self, overall_evaluation=None, overall_evaluation_status=None, recruiter_user_id=None, video_screen_id=None, answer_ratings=None, role_name=None):  # noqa: E501
        """GiveEvaluationRequest - a model defined in Swagger"""  # noqa: E501
        self._overall_evaluation = None
        self._overall_evaluation_status = None
        self._recruiter_user_id = None
        self._video_screen_id = None
        self._answer_ratings = None
        self._role_name = None
        self.discriminator = None
        self.overall_evaluation = overall_evaluation
        self.overall_evaluation_status = overall_evaluation_status
        self.recruiter_user_id = recruiter_user_id
        self.video_screen_id = video_screen_id
        self.answer_ratings = answer_ratings
        self.role_name = role_name

    @property
    def overall_evaluation(self):
        """Gets the overall_evaluation of this GiveEvaluationRequest.  # noqa: E501

        Comment given by evaluator.  # noqa: E501

        :return: The overall_evaluation of this GiveEvaluationRequest.  # noqa: E501
        :rtype: str
        """
        return self._overall_evaluation

    @overall_evaluation.setter
    def overall_evaluation(self, overall_evaluation):
        """Sets the overall_evaluation of this GiveEvaluationRequest.

        Comment given by evaluator.  # noqa: E501

        :param overall_evaluation: The overall_evaluation of this GiveEvaluationRequest.  # noqa: E501
        :type: str
        """
        if overall_evaluation is None:
            raise ValueError("Invalid value for `overall_evaluation`, must not be `None`")  # noqa: E501

        self._overall_evaluation = overall_evaluation

    @property
    def overall_evaluation_status(self):
        """Gets the overall_evaluation_status of this GiveEvaluationRequest.  # noqa: E501

        This can be Yes, No, Maybe. This is the conclusion of the overall evaluation, indicates to consider the candidate or not.  # noqa: E501

        :return: The overall_evaluation_status of this GiveEvaluationRequest.  # noqa: E501
        :rtype: str
        """
        return self._overall_evaluation_status

    @overall_evaluation_status.setter
    def overall_evaluation_status(self, overall_evaluation_status):
        """Sets the overall_evaluation_status of this GiveEvaluationRequest.

        This can be Yes, No, Maybe. This is the conclusion of the overall evaluation, indicates to consider the candidate or not.  # noqa: E501

        :param overall_evaluation_status: The overall_evaluation_status of this GiveEvaluationRequest.  # noqa: E501
        :type: str
        """
        if overall_evaluation_status is None:
            raise ValueError("Invalid value for `overall_evaluation_status`, must not be `None`")  # noqa: E501

        self._overall_evaluation_status = overall_evaluation_status

    @property
    def recruiter_user_id(self):
        """Gets the recruiter_user_id of this GiveEvaluationRequest.  # noqa: E501

        user id of the evaluator.  # noqa: E501

        :return: The recruiter_user_id of this GiveEvaluationRequest.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_user_id

    @recruiter_user_id.setter
    def recruiter_user_id(self, recruiter_user_id):
        """Sets the recruiter_user_id of this GiveEvaluationRequest.

        user id of the evaluator.  # noqa: E501

        :param recruiter_user_id: The recruiter_user_id of this GiveEvaluationRequest.  # noqa: E501
        :type: str
        """
        if recruiter_user_id is None:
            raise ValueError("Invalid value for `recruiter_user_id`, must not be `None`")  # noqa: E501

        self._recruiter_user_id = recruiter_user_id

    @property
    def video_screen_id(self):
        """Gets the video_screen_id of this GiveEvaluationRequest.  # noqa: E501

        Interview id.  # noqa: E501

        :return: The video_screen_id of this GiveEvaluationRequest.  # noqa: E501
        :rtype: str
        """
        return self._video_screen_id

    @video_screen_id.setter
    def video_screen_id(self, video_screen_id):
        """Sets the video_screen_id of this GiveEvaluationRequest.

        Interview id.  # noqa: E501

        :param video_screen_id: The video_screen_id of this GiveEvaluationRequest.  # noqa: E501
        :type: str
        """
        if video_screen_id is None:
            raise ValueError("Invalid value for `video_screen_id`, must not be `None`")  # noqa: E501

        self._video_screen_id = video_screen_id

    @property
    def answer_ratings(self):
        """Gets the answer_ratings of this GiveEvaluationRequest.  # noqa: E501

        Rating given for each question.  # noqa: E501

        :return: The answer_ratings of this GiveEvaluationRequest.  # noqa: E501
        :rtype: list[GiveEvaluationRequestAnswerRatings]
        """
        return self._answer_ratings

    @answer_ratings.setter
    def answer_ratings(self, answer_ratings):
        """Sets the answer_ratings of this GiveEvaluationRequest.

        Rating given for each question.  # noqa: E501

        :param answer_ratings: The answer_ratings of this GiveEvaluationRequest.  # noqa: E501
        :type: list[GiveEvaluationRequestAnswerRatings]
        """
        if answer_ratings is None:
            raise ValueError("Invalid value for `answer_ratings`, must not be `None`")  # noqa: E501

        self._answer_ratings = answer_ratings

    @property
    def role_name(self):
        """Gets the role_name of this GiveEvaluationRequest.  # noqa: E501

        Role name for the evaluator.  # noqa: E501

        :return: The role_name of this GiveEvaluationRequest.  # noqa: E501
        :rtype: str
        """
        return self._role_name

    @role_name.setter
    def role_name(self, role_name):
        """Sets the role_name of this GiveEvaluationRequest.

        Role name for the evaluator.  # noqa: E501

        :param role_name: The role_name of this GiveEvaluationRequest.  # noqa: E501
        :type: str
        """
        if role_name is None:
            raise ValueError("Invalid value for `role_name`, must not be `None`")  # noqa: E501

        self._role_name = role_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GiveEvaluationRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GiveEvaluationRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    apply-api

    The Apply API allows for seamless integration of the Phenom systems, enabling partners to push applications directly. This API also enables partners to integrate the Phenom Quick application process into their own job boards, while still maintaining control over the candidate experience. As a result, candidates can submit their applications without needing to visit the customer career site.  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class ErrorResponse(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status': 'str',
        'title': 'str',
        'type': 'str',
        'error': 'str',
        'details': 'str',
        'instance': 'str',
        'timestamp': 'str'
    }

    attribute_map = {
        'status': 'status',
        'title': 'title',
        'type': 'type',
        'error': 'error',
        'details': 'details',
        'instance': 'instance',
        'timestamp': 'timestamp'
    }

    def __init__(self, status=None, title=None, type=None, error=None, details=None, instance=None, timestamp=None):  # noqa: E501
        """ErrorResponse - a model defined in Swagger"""  # noqa: E501
        self._status = None
        self._title = None
        self._type = None
        self._error = None
        self._details = None
        self._instance = None
        self._timestamp = None
        self.discriminator = None
        if status is not None:
            self.status = status
        if title is not None:
            self.title = title
        if type is not None:
            self.type = type
        if error is not None:
            self.error = error
        if details is not None:
            self.details = details
        if instance is not None:
            self.instance = instance
        if timestamp is not None:
            self.timestamp = timestamp

    @property
    def status(self):
        """Gets the status of this ErrorResponse.  # noqa: E501

        Status of the response. It will contain HTTP status code in case of failures.  # noqa: E501

        :return: The status of this ErrorResponse.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ErrorResponse.

        Status of the response. It will contain HTTP status code in case of failures.  # noqa: E501

        :param status: The status of this ErrorResponse.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def title(self):
        """Gets the title of this ErrorResponse.  # noqa: E501

        Error message of the response. It gives a short brief on the error.  # noqa: E501

        :return: The title of this ErrorResponse.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this ErrorResponse.

        Error message of the response. It gives a short brief on the error.  # noqa: E501

        :param title: The title of this ErrorResponse.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def type(self):
        """Gets the type of this ErrorResponse.  # noqa: E501

        Type of the error. It gives a brief on the type of error.  # noqa: E501

        :return: The type of this ErrorResponse.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ErrorResponse.

        Type of the error. It gives a brief on the type of error.  # noqa: E501

        :param type: The type of this ErrorResponse.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def error(self):
        """Gets the error of this ErrorResponse.  # noqa: E501

        This describes Error/Status Code in case of errors.  # noqa: E501

        :return: The error of this ErrorResponse.  # noqa: E501
        :rtype: str
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this ErrorResponse.

        This describes Error/Status Code in case of errors.  # noqa: E501

        :param error: The error of this ErrorResponse.  # noqa: E501
        :type: str
        """

        self._error = error

    @property
    def details(self):
        """Gets the details of this ErrorResponse.  # noqa: E501

        Error message of the response. This describes the details of the error.  # noqa: E501

        :return: The details of this ErrorResponse.  # noqa: E501
        :rtype: str
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this ErrorResponse.

        Error message of the response. This describes the details of the error.  # noqa: E501

        :param details: The details of this ErrorResponse.  # noqa: E501
        :type: str
        """

        self._details = details

    @property
    def instance(self):
        """Gets the instance of this ErrorResponse.  # noqa: E501

        URI of the instance.  # noqa: E501

        :return: The instance of this ErrorResponse.  # noqa: E501
        :rtype: str
        """
        return self._instance

    @instance.setter
    def instance(self, instance):
        """Sets the instance of this ErrorResponse.

        URI of the instance.  # noqa: E501

        :param instance: The instance of this ErrorResponse.  # noqa: E501
        :type: str
        """

        self._instance = instance

    @property
    def timestamp(self):
        """Gets the timestamp of this ErrorResponse.  # noqa: E501

        Timestamp of the response.  # noqa: E501

        :return: The timestamp of this ErrorResponse.  # noqa: E501
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this ErrorResponse.

        Timestamp of the response.  # noqa: E501

        :param timestamp: The timestamp of this ErrorResponse.  # noqa: E501
        :type: str
        """

        self._timestamp = timestamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ErrorResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ErrorResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    videoplatform-api

    Interview Screening APIs allows to invite candidate to interview, evaluate and review candidates interview performances.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phenom.commons.api_client import ApiClient


class QuestionsApi(object):
    base_path = "/interview-screening"  # your base path

    def __init__(self, token, gateway_url, apikey, api_client=None):
        if api_client is None:
            api_client = ApiClient(gateway_url + self.base_path, apikey, token)
        self.api_client = api_client

    def create_new_question_for_interview(self, body, **kwargs):  # noqa: E501
        """Create Question  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_new_question_for_interview(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateQuestionRequest body: (required)
        :return: CreateQuestionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_new_question_for_interview_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_new_question_for_interview_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def create_new_question_for_interview_with_http_info(self, body, **kwargs):  # noqa: E501
        """Create Question  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_new_question_for_interview_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateQuestionRequest body: (required)
        :return: CreateQuestionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_new_question_for_interview" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_new_question_for_interview`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/questions', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateQuestionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_the_question_for_question_id(self, questionnaire_id, question_id, **kwargs):  # noqa: E501
        """Delete Question  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_the_question_for_question_id(questionnaire_id, question_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str questionnaire_id: (required)
        :param str question_id: (required)
        :return: DeleteQuestionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_the_question_for_question_id_with_http_info(questionnaire_id, question_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_the_question_for_question_id_with_http_info(questionnaire_id, question_id, **kwargs)  # noqa: E501
            return data

    def delete_the_question_for_question_id_with_http_info(self, questionnaire_id, question_id, **kwargs):  # noqa: E501
        """Delete Question  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_the_question_for_question_id_with_http_info(questionnaire_id, question_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str questionnaire_id: (required)
        :param str question_id: (required)
        :return: DeleteQuestionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['questionnaire_id', 'question_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_the_question_for_question_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'questionnaire_id' is set
        if ('questionnaire_id' not in params or
                params['questionnaire_id'] is None):
            raise ValueError("Missing the required parameter `questionnaire_id` when calling `delete_the_question_for_question_id`")  # noqa: E501
        # verify the required parameter 'question_id' is set
        if ('question_id' not in params or
                params['question_id'] is None):
            raise ValueError("Missing the required parameter `question_id` when calling `delete_the_question_for_question_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'question_id' in params:
            path_params['questionId'] = params['question_id']  # noqa: E501

        query_params = []
        if 'questionnaire_id' in params:
            query_params.append(('questionnaireId', params['questionnaire_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/questions/{questionId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteQuestionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_questions(self, _from, **kwargs):  # noqa: E501
        """Get Questions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_questions(_from, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float _from: (required)
        :return: GetAllQuestionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_questions_with_http_info(_from, **kwargs)  # noqa: E501
        else:
            (data) = self.get_all_questions_with_http_info(_from, **kwargs)  # noqa: E501
            return data

    def get_all_questions_with_http_info(self, _from, **kwargs):  # noqa: E501
        """Get Questions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_questions_with_http_info(_from, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float _from: (required)
        :return: GetAllQuestionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_questions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter '_from' is set
        if ('_from' not in params or
                params['_from'] is None):
            raise ValueError("Missing the required parameter `_from` when calling `get_all_questions`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/questions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetAllQuestionsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_question_details(self, question_id, **kwargs):  # noqa: E501
        """Get Question Details  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_question_details(question_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str question_id: (required)
        :return: GetQuestionDetailsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_question_details_with_http_info(question_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_question_details_with_http_info(question_id, **kwargs)  # noqa: E501
            return data

    def get_question_details_with_http_info(self, question_id, **kwargs):  # noqa: E501
        """Get Question Details  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_question_details_with_http_info(question_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str question_id: (required)
        :return: GetQuestionDetailsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['question_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_question_details" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'question_id' is set
        if ('question_id' not in params or
                params['question_id'] is None):
            raise ValueError("Missing the required parameter `question_id` when calling `get_question_details`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'question_id' in params:
            path_params['questionId'] = params['question_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/questions/{questionId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetQuestionDetailsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_question_types(self, **kwargs):  # noqa: E501
        """All Question Types  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_question_types(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: GetAllQuestionTypes
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_question_types_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_question_types_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_question_types_with_http_info(self, **kwargs):  # noqa: E501
        """All Question Types  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_question_types_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: GetAllQuestionTypes
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_question_types" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/questions/types', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetAllQuestionTypes',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_question_data(self, body, **kwargs):  # noqa: E501
        """Update Question  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_question_data(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateQuestionRequest body: (required)
        :return: UpdateQuestionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_question_data_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.update_question_data_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def update_question_data_with_http_info(self, body, **kwargs):  # noqa: E501
        """Update Question  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_question_data_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateQuestionRequest body: (required)
        :return: UpdateQuestionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_question_data" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_question_data`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/questions', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UpdateQuestionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class CreateProjectRequest(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'project_name': 'str',
        'project_description': 'str',
        'is_confidential': 'bool',
        'category_list': 'list[CreateProjectRequestCategoryList]',
        'end_date': 'str',
        'hiring_team_list': 'list[CreateProjectRequestHiringTeamList]',
        'project_attachment_list': 'list[CreateProjectRequestProjectAttachmentList]',
        'workflow_id': 'str',
        'workflow_name': 'str',
        'created_recruiter_info': 'CreateProjectRequestCreatedRecruiterInfo',
        'status': 'str'
    }

    attribute_map = {
        'project_name': 'projectName',
        'project_description': 'projectDescription',
        'is_confidential': 'isConfidential',
        'category_list': 'categoryList',
        'end_date': 'endDate',
        'hiring_team_list': 'hiringTeamList',
        'project_attachment_list': 'projectAttachmentList',
        'workflow_id': 'workflowId',
        'workflow_name': 'workflowName',
        'created_recruiter_info': 'createdRecruiterInfo',
        'status': 'status'
    }

    def __init__(self, project_name=None, project_description=None, is_confidential=None, category_list=None, end_date=None, hiring_team_list=None, project_attachment_list=None, workflow_id=None, workflow_name=None, created_recruiter_info=None, status=None):  # noqa: E501
        """CreateProjectRequest - a model defined in Swagger"""  # noqa: E501
        self._project_name = None
        self._project_description = None
        self._is_confidential = None
        self._category_list = None
        self._end_date = None
        self._hiring_team_list = None
        self._project_attachment_list = None
        self._workflow_id = None
        self._workflow_name = None
        self._created_recruiter_info = None
        self._status = None
        self.discriminator = None
        self.project_name = project_name
        if project_description is not None:
            self.project_description = project_description
        self.is_confidential = is_confidential
        if category_list is not None:
            self.category_list = category_list
        if end_date is not None:
            self.end_date = end_date
        self.hiring_team_list = hiring_team_list
        if project_attachment_list is not None:
            self.project_attachment_list = project_attachment_list
        self.workflow_id = workflow_id
        self.workflow_name = workflow_name
        self.created_recruiter_info = created_recruiter_info
        self.status = status

    @property
    def project_name(self):
        """Gets the project_name of this CreateProjectRequest.  # noqa: E501

        Name of the project.  # noqa: E501

        :return: The project_name of this CreateProjectRequest.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this CreateProjectRequest.

        Name of the project.  # noqa: E501

        :param project_name: The project_name of this CreateProjectRequest.  # noqa: E501
        :type: str
        """
        if project_name is None:
            raise ValueError("Invalid value for `project_name`, must not be `None`")  # noqa: E501

        self._project_name = project_name

    @property
    def project_description(self):
        """Gets the project_description of this CreateProjectRequest.  # noqa: E501

        Description of the project.  # noqa: E501

        :return: The project_description of this CreateProjectRequest.  # noqa: E501
        :rtype: str
        """
        return self._project_description

    @project_description.setter
    def project_description(self, project_description):
        """Sets the project_description of this CreateProjectRequest.

        Description of the project.  # noqa: E501

        :param project_description: The project_description of this CreateProjectRequest.  # noqa: E501
        :type: str
        """

        self._project_description = project_description

    @property
    def is_confidential(self):
        """Gets the is_confidential of this CreateProjectRequest.  # noqa: E501

        Flag indicating whether the project is confidential.  # noqa: E501

        :return: The is_confidential of this CreateProjectRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_confidential

    @is_confidential.setter
    def is_confidential(self, is_confidential):
        """Sets the is_confidential of this CreateProjectRequest.

        Flag indicating whether the project is confidential.  # noqa: E501

        :param is_confidential: The is_confidential of this CreateProjectRequest.  # noqa: E501
        :type: bool
        """
        if is_confidential is None:
            raise ValueError("Invalid value for `is_confidential`, must not be `None`")  # noqa: E501

        self._is_confidential = is_confidential

    @property
    def category_list(self):
        """Gets the category_list of this CreateProjectRequest.  # noqa: E501

        List of project categories.  # noqa: E501

        :return: The category_list of this CreateProjectRequest.  # noqa: E501
        :rtype: list[CreateProjectRequestCategoryList]
        """
        return self._category_list

    @category_list.setter
    def category_list(self, category_list):
        """Sets the category_list of this CreateProjectRequest.

        List of project categories.  # noqa: E501

        :param category_list: The category_list of this CreateProjectRequest.  # noqa: E501
        :type: list[CreateProjectRequestCategoryList]
        """

        self._category_list = category_list

    @property
    def end_date(self):
        """Gets the end_date of this CreateProjectRequest.  # noqa: E501

        End date of the project.  # noqa: E501

        :return: The end_date of this CreateProjectRequest.  # noqa: E501
        :rtype: str
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this CreateProjectRequest.

        End date of the project.  # noqa: E501

        :param end_date: The end_date of this CreateProjectRequest.  # noqa: E501
        :type: str
        """

        self._end_date = end_date

    @property
    def hiring_team_list(self):
        """Gets the hiring_team_list of this CreateProjectRequest.  # noqa: E501

        List of hiring team members.  # noqa: E501

        :return: The hiring_team_list of this CreateProjectRequest.  # noqa: E501
        :rtype: list[CreateProjectRequestHiringTeamList]
        """
        return self._hiring_team_list

    @hiring_team_list.setter
    def hiring_team_list(self, hiring_team_list):
        """Sets the hiring_team_list of this CreateProjectRequest.

        List of hiring team members.  # noqa: E501

        :param hiring_team_list: The hiring_team_list of this CreateProjectRequest.  # noqa: E501
        :type: list[CreateProjectRequestHiringTeamList]
        """
        if hiring_team_list is None:
            raise ValueError("Invalid value for `hiring_team_list`, must not be `None`")  # noqa: E501

        self._hiring_team_list = hiring_team_list

    @property
    def project_attachment_list(self):
        """Gets the project_attachment_list of this CreateProjectRequest.  # noqa: E501

        List of project attachments.  # noqa: E501

        :return: The project_attachment_list of this CreateProjectRequest.  # noqa: E501
        :rtype: list[CreateProjectRequestProjectAttachmentList]
        """
        return self._project_attachment_list

    @project_attachment_list.setter
    def project_attachment_list(self, project_attachment_list):
        """Sets the project_attachment_list of this CreateProjectRequest.

        List of project attachments.  # noqa: E501

        :param project_attachment_list: The project_attachment_list of this CreateProjectRequest.  # noqa: E501
        :type: list[CreateProjectRequestProjectAttachmentList]
        """

        self._project_attachment_list = project_attachment_list

    @property
    def workflow_id(self):
        """Gets the workflow_id of this CreateProjectRequest.  # noqa: E501

        ID of the workflow associated with the project.  # noqa: E501

        :return: The workflow_id of this CreateProjectRequest.  # noqa: E501
        :rtype: str
        """
        return self._workflow_id

    @workflow_id.setter
    def workflow_id(self, workflow_id):
        """Sets the workflow_id of this CreateProjectRequest.

        ID of the workflow associated with the project.  # noqa: E501

        :param workflow_id: The workflow_id of this CreateProjectRequest.  # noqa: E501
        :type: str
        """
        if workflow_id is None:
            raise ValueError("Invalid value for `workflow_id`, must not be `None`")  # noqa: E501

        self._workflow_id = workflow_id

    @property
    def workflow_name(self):
        """Gets the workflow_name of this CreateProjectRequest.  # noqa: E501

        Name of the workflow associated with the project.  # noqa: E501

        :return: The workflow_name of this CreateProjectRequest.  # noqa: E501
        :rtype: str
        """
        return self._workflow_name

    @workflow_name.setter
    def workflow_name(self, workflow_name):
        """Sets the workflow_name of this CreateProjectRequest.

        Name of the workflow associated with the project.  # noqa: E501

        :param workflow_name: The workflow_name of this CreateProjectRequest.  # noqa: E501
        :type: str
        """
        if workflow_name is None:
            raise ValueError("Invalid value for `workflow_name`, must not be `None`")  # noqa: E501

        self._workflow_name = workflow_name

    @property
    def created_recruiter_info(self):
        """Gets the created_recruiter_info of this CreateProjectRequest.  # noqa: E501


        :return: The created_recruiter_info of this CreateProjectRequest.  # noqa: E501
        :rtype: CreateProjectRequestCreatedRecruiterInfo
        """
        return self._created_recruiter_info

    @created_recruiter_info.setter
    def created_recruiter_info(self, created_recruiter_info):
        """Sets the created_recruiter_info of this CreateProjectRequest.


        :param created_recruiter_info: The created_recruiter_info of this CreateProjectRequest.  # noqa: E501
        :type: CreateProjectRequestCreatedRecruiterInfo
        """
        if created_recruiter_info is None:
            raise ValueError("Invalid value for `created_recruiter_info`, must not be `None`")  # noqa: E501

        self._created_recruiter_info = created_recruiter_info

    @property
    def status(self):
        """Gets the status of this CreateProjectRequest.  # noqa: E501

        Status of the project.  # noqa: E501

        :return: The status of this CreateProjectRequest.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CreateProjectRequest.

        Status of the project.  # noqa: E501

        :param status: The status of this CreateProjectRequest.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateProjectRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateProjectRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    candidates-attachments-api

    The Candidate APIs allows you to add, update and delete candidate attachments.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import apis into sdk package
from phenom.api.candidatesAttachmentsApi.candidate_attachments_api import CandidateAttachmentsApi
# import ApiClient
from phenom.commons.api_client import ApiClient
from phenom.commons.configuration import Configuration
# import models into sdk package
from phenom.api.candidatesAttachmentsApi.models.add_attachments_request import AddAttachmentsRequest
from phenom.api.candidatesAttachmentsApi.models.attachment import Attachment
from phenom.api.candidatesAttachmentsApi.models.attachment_attachments import AttachmentAttachments
from phenom.api.candidatesAttachmentsApi.models.attachment_update_response import AttachmentUpdateResponse
from phenom.api.candidatesAttachmentsApi.models.delete_attachment_request import DeleteAttachmentRequest
from phenom.api.candidatesAttachmentsApi.models.delete_attachment_request_attachments import DeleteAttachmentRequestAttachments
from phenom.api.candidatesAttachmentsApi.models.error import Error
from phenom.api.candidatesAttachmentsApi.models.error_message import ErrorMessage
from phenom.api.candidatesAttachmentsApi.models.pre_signed_url import PreSignedUrl



# coding: utf-8

"""
    applicants-api

    This API collection enables seamless operations by facilitating the retrieval of essential applicant details, updating and managing hiring statuses for candidates, assigning multiple candidates as leads for specific job roles, and obtaining detailed activity logs associated with applicants.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class HiringStatusActivitiesPagination(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'size': 'float',
        '_from': 'float',
        'total_count': 'float'
    }

    attribute_map = {
        'size': 'size',
        '_from': 'from',
        'total_count': 'totalCount'
    }

    def __init__(self, size=None, _from=None, total_count=None):  # noqa: E501
        """HiringStatusActivitiesPagination - a model defined in Swagger"""  # noqa: E501
        self._size = None
        self.__from = None
        self._total_count = None
        self.discriminator = None
        if size is not None:
            self.size = size
        if _from is not None:
            self._from = _from
        if total_count is not None:
            self.total_count = total_count

    @property
    def size(self):
        """Gets the size of this HiringStatusActivitiesPagination.  # noqa: E501

        Number of items per page.  # noqa: E501

        :return: The size of this HiringStatusActivitiesPagination.  # noqa: E501
        :rtype: float
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this HiringStatusActivitiesPagination.

        Number of items per page.  # noqa: E501

        :param size: The size of this HiringStatusActivitiesPagination.  # noqa: E501
        :type: float
        """

        self._size = size

    @property
    def _from(self):
        """Gets the _from of this HiringStatusActivitiesPagination.  # noqa: E501

        Starting index of the items in the current page.  # noqa: E501

        :return: The _from of this HiringStatusActivitiesPagination.  # noqa: E501
        :rtype: float
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this HiringStatusActivitiesPagination.

        Starting index of the items in the current page.  # noqa: E501

        :param _from: The _from of this HiringStatusActivitiesPagination.  # noqa: E501
        :type: float
        """

        self.__from = _from

    @property
    def total_count(self):
        """Gets the total_count of this HiringStatusActivitiesPagination.  # noqa: E501

        Total count of hiring status activities across all pages.  # noqa: E501

        :return: The total_count of this HiringStatusActivitiesPagination.  # noqa: E501
        :rtype: float
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this HiringStatusActivitiesPagination.

        Total count of hiring status activities across all pages.  # noqa: E501

        :param total_count: The total_count of this HiringStatusActivitiesPagination.  # noqa: E501
        :type: float
        """

        self._total_count = total_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HiringStatusActivitiesPagination, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HiringStatusActivitiesPagination):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from phenom.api.hrm.jobs_api import JobsApi

class HiringManager(object):
    def __init__(self, token, gateway_url, apikey=None):
        self.__token = token
        self.__gateway_url = gateway_url
        self.__apikey = apikey
    def jobs_api(self):
        return JobsApi(self.__token, self.__gateway_url, self.__apikey)


# coding: utf-8

"""
    videoplatform-api

    Interview Screening APIs allows to invite candidate to interview, evaluate and review candidates interview performances.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phenom.commons.api_client import ApiClient


class QuestionnaireTemplatesApi(object):
    base_path = "/interview-screening"  # your base path

    def __init__(self, token, gateway_url, apikey, api_client=None):
        if api_client is None:
            api_client = ApiClient(gateway_url + self.base_path, apikey, token)
        self.api_client = api_client

    def create_questionnaire(self, body, **kwargs):  # noqa: E501
        """Create Questionnaire  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_questionnaire(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateQuestionnaireRequest body: (required)
        :return: CreateQuestionnaireResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_questionnaire_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_questionnaire_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def create_questionnaire_with_http_info(self, body, **kwargs):  # noqa: E501
        """Create Questionnaire  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_questionnaire_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateQuestionnaireRequest body: (required)
        :return: CreateQuestionnaireResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_questionnaire" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_questionnaire`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/questionnaire-templates', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateQuestionnaireResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def del_questionnaire(self, questionnaire_id, **kwargs):  # noqa: E501
        """Delete Questionnaire  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.del_questionnaire(questionnaire_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str questionnaire_id: (required)
        :return: DeleteQuestionnaireResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.del_questionnaire_with_http_info(questionnaire_id, **kwargs)  # noqa: E501
        else:
            (data) = self.del_questionnaire_with_http_info(questionnaire_id, **kwargs)  # noqa: E501
            return data

    def del_questionnaire_with_http_info(self, questionnaire_id, **kwargs):  # noqa: E501
        """Delete Questionnaire  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.del_questionnaire_with_http_info(questionnaire_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str questionnaire_id: (required)
        :return: DeleteQuestionnaireResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['questionnaire_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method del_questionnaire" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'questionnaire_id' is set
        if ('questionnaire_id' not in params or
                params['questionnaire_id'] is None):
            raise ValueError("Missing the required parameter `questionnaire_id` when calling `del_questionnaire`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'questionnaire_id' in params:
            path_params['questionnaireId'] = params['questionnaire_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/questionnaire-templates/{questionnaireId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteQuestionnaireResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_questionnaire(self, questionnaire_id, **kwargs):  # noqa: E501
        """Get Questionnaire Details  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_questionnaire(questionnaire_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str questionnaire_id: (required)
        :return: GetQuestionnaireDetailsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_questionnaire_with_http_info(questionnaire_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_questionnaire_with_http_info(questionnaire_id, **kwargs)  # noqa: E501
            return data

    def get_questionnaire_with_http_info(self, questionnaire_id, **kwargs):  # noqa: E501
        """Get Questionnaire Details  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_questionnaire_with_http_info(questionnaire_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str questionnaire_id: (required)
        :return: GetQuestionnaireDetailsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['questionnaire_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_questionnaire" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'questionnaire_id' is set
        if ('questionnaire_id' not in params or
                params['questionnaire_id'] is None):
            raise ValueError("Missing the required parameter `questionnaire_id` when calling `get_questionnaire`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'questionnaire_id' in params:
            path_params['questionnaireId'] = params['questionnaire_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/questionnaire-templates/{questionnaireId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetQuestionnaireDetailsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_questionnaires(self, _from, **kwargs):  # noqa: E501
        """Get Questionnaires  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_questionnaires(_from, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float _from: (required)
        :param str search_keyword:
        :return: GetAllQuestionnairesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_questionnaires_with_http_info(_from, **kwargs)  # noqa: E501
        else:
            (data) = self.get_questionnaires_with_http_info(_from, **kwargs)  # noqa: E501
            return data

    def get_questionnaires_with_http_info(self, _from, **kwargs):  # noqa: E501
        """Get Questionnaires  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_questionnaires_with_http_info(_from, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float _from: (required)
        :param str search_keyword:
        :return: GetAllQuestionnairesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'search_keyword']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_questionnaires" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter '_from' is set
        if ('_from' not in params or
                params['_from'] is None):
            raise ValueError("Missing the required parameter `_from` when calling `get_questionnaires`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'search_keyword' in params:
            query_params.append(('searchKeyword', params['search_keyword']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/questionnaire-templates', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetAllQuestionnairesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_questionnaires(self, body, questionnaire_id, **kwargs):  # noqa: E501
        """Update Questionnaire  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_questionnaires(body, questionnaire_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateQuestionnaireRequest body: (required)
        :param str questionnaire_id: (required)
        :return: UpdateQuestionnaireResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_questionnaires_with_http_info(body, questionnaire_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_questionnaires_with_http_info(body, questionnaire_id, **kwargs)  # noqa: E501
            return data

    def update_questionnaires_with_http_info(self, body, questionnaire_id, **kwargs):  # noqa: E501
        """Update Questionnaire  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_questionnaires_with_http_info(body, questionnaire_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateQuestionnaireRequest body: (required)
        :param str questionnaire_id: (required)
        :return: UpdateQuestionnaireResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'questionnaire_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_questionnaires" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_questionnaires`")  # noqa: E501
        # verify the required parameter 'questionnaire_id' is set
        if ('questionnaire_id' not in params or
                params['questionnaire_id'] is None):
            raise ValueError("Missing the required parameter `questionnaire_id` when calling `update_questionnaires`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'questionnaire_id' in params:
            path_params['questionnaireId'] = params['questionnaire_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/questionnaire-templates/{questionnaireId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UpdateQuestionnaireResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    servicehub-scim-api

    API endpoints for user management, utilizing the SCIM protocol.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class ScimRoleList(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'schemas': 'list[str]',
        'resources': 'list[ScimRoleListResources]',
        'start_index': 'int',
        'items_per_page': 'int',
        'total_results': 'int',
        'meta': 'ScimRoleListMeta'
    }

    attribute_map = {
        'schemas': 'schemas',
        'resources': 'Resources',
        'start_index': 'startIndex',
        'items_per_page': 'itemsPerPage',
        'total_results': 'totalResults',
        'meta': 'meta'
    }

    def __init__(self, schemas=None, resources=None, start_index=None, items_per_page=None, total_results=None, meta=None):  # noqa: E501
        """ScimRoleList - a model defined in Swagger"""  # noqa: E501
        self._schemas = None
        self._resources = None
        self._start_index = None
        self._items_per_page = None
        self._total_results = None
        self._meta = None
        self.discriminator = None
        if schemas is not None:
            self.schemas = schemas
        if resources is not None:
            self.resources = resources
        if start_index is not None:
            self.start_index = start_index
        if items_per_page is not None:
            self.items_per_page = items_per_page
        if total_results is not None:
            self.total_results = total_results
        if meta is not None:
            self.meta = meta

    @property
    def schemas(self):
        """Gets the schemas of this ScimRoleList.  # noqa: E501

        An array of strings indicating the available schemas for the resource.  # noqa: E501

        :return: The schemas of this ScimRoleList.  # noqa: E501
        :rtype: list[str]
        """
        return self._schemas

    @schemas.setter
    def schemas(self, schemas):
        """Sets the schemas of this ScimRoleList.

        An array of strings indicating the available schemas for the resource.  # noqa: E501

        :param schemas: The schemas of this ScimRoleList.  # noqa: E501
        :type: list[str]
        """

        self._schemas = schemas

    @property
    def resources(self):
        """Gets the resources of this ScimRoleList.  # noqa: E501

        List of SCIM Roles.  # noqa: E501

        :return: The resources of this ScimRoleList.  # noqa: E501
        :rtype: list[ScimRoleListResources]
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """Sets the resources of this ScimRoleList.

        List of SCIM Roles.  # noqa: E501

        :param resources: The resources of this ScimRoleList.  # noqa: E501
        :type: list[ScimRoleListResources]
        """

        self._resources = resources

    @property
    def start_index(self):
        """Gets the start_index of this ScimRoleList.  # noqa: E501

        Index of the first result in the current set of search results.  # noqa: E501

        :return: The start_index of this ScimRoleList.  # noqa: E501
        :rtype: int
        """
        return self._start_index

    @start_index.setter
    def start_index(self, start_index):
        """Sets the start_index of this ScimRoleList.

        Index of the first result in the current set of search results.  # noqa: E501

        :param start_index: The start_index of this ScimRoleList.  # noqa: E501
        :type: int
        """

        self._start_index = start_index

    @property
    def items_per_page(self):
        """Gets the items_per_page of this ScimRoleList.  # noqa: E501

        Number of items per page in the current set of search results.  # noqa: E501

        :return: The items_per_page of this ScimRoleList.  # noqa: E501
        :rtype: int
        """
        return self._items_per_page

    @items_per_page.setter
    def items_per_page(self, items_per_page):
        """Sets the items_per_page of this ScimRoleList.

        Number of items per page in the current set of search results.  # noqa: E501

        :param items_per_page: The items_per_page of this ScimRoleList.  # noqa: E501
        :type: int
        """

        self._items_per_page = items_per_page

    @property
    def total_results(self):
        """Gets the total_results of this ScimRoleList.  # noqa: E501

        Total number of results.  # noqa: E501

        :return: The total_results of this ScimRoleList.  # noqa: E501
        :rtype: int
        """
        return self._total_results

    @total_results.setter
    def total_results(self, total_results):
        """Sets the total_results of this ScimRoleList.

        Total number of results.  # noqa: E501

        :param total_results: The total_results of this ScimRoleList.  # noqa: E501
        :type: int
        """

        self._total_results = total_results

    @property
    def meta(self):
        """Gets the meta of this ScimRoleList.  # noqa: E501


        :return: The meta of this ScimRoleList.  # noqa: E501
        :rtype: ScimRoleListMeta
        """
        return self._meta

    @meta.setter
    def meta(self, meta):
        """Sets the meta of this ScimRoleList.


        :param meta: The meta of this ScimRoleList.  # noqa: E501
        :type: ScimRoleListMeta
        """

        self._meta = meta

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ScimRoleList, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScimRoleList):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
